Bounded

Struct Bounded 

pub struct Bounded<T, const MAX: usize>(pub T);
A newtype wrapper for T which modifies the Encode and Decode impls to be bounded by some upper limit MAX. Implementations are expected to error eagerly if the limit is exceeded.

What exactly MAX represents depends on the type T. Here are some instances:

  • arrays/slices: The maximum number of elements.
  • strings: The maximum number of utf16 code units.
  • RawBytes: The maximum number of bytes.

Tuple Fields

0: T

Implementations

Source

impl<T, const MAX: usize> Bounded<T, MAX>

pub fn map<F: FnOnce(T) -> U, U>(self, f: F) -> Bounded<U, MAX>

pub fn map_into<U: From<T>>(self) -> Bounded<U, MAX>