pub struct Bounded<T, const MAX: usize>(pub T);Expand description
A newtype wrapper for T which modifies the Encode and
Decode impls to be bounded by some upper limit MAX.
Implementations are expected to error eagerly if the limit is exceeded.
What exactly MAX represents depends on the type T. Here are some
instances:
- arrays/slices: The maximum number of elements.
- strings: The maximum number of utf16 code units.
RawBytes: The maximum number of bytes.
Tuple Fields
0: TImplementations